@@ -62,7 +62,12 @@ Conf *conf; // Global variable needed for Yacc. Sigh.
 Conf *read_conf()
 {
     conf = malloc(sizeof(Conf));
+    if (conf == NULL)
+        errx(1, "read_conf: unable to allocate memory");
     conf->spool_dir = NULL;
+    conf->notify_failure_interval = 0;
+    conf->notify_failure_cmd = NULL;
+    conf->notify_success_cmd = NULL;
 
     int i;
     for (i = 0; CONF_PATHS[i] != NULL; i += 1) {
@@ -90,27 +95,24 @@ int try_conf_path(const char *path)
 {
     char *cnd_path = expand_path(path);
     if (cnd_path == NULL) {
-        free(cnd_path);
         return -1;
     }
 
-    // See whether the configuration exists at 'path'.
-    struct stat conf_st;
-    if (stat(cnd_path, &conf_st) == -1) {
-        free(cnd_path);
-        return 1;
-    }
-
     yycin = fopen(cnd_path, "rt");
+    free(cnd_path);
     if (yycin == NULL) {
-        free(cnd_path);
+        if (errno == ENOENT)
+            return 1;
         return -1;
     }
-    free(cnd_path);
     
-    if (yycparse() != 0)
+    if (yycparse() != 0) {
+        fclose(yycin);
         return -1;
-    
+    }
+
+    fclose(yycin);
+
     return 0;
 }
 
@@ -230,6 +232,8 @@ char *fdrdline(int fd)
         if (line == NULL) {
             line_alloc = i + 1;
             line = malloc(line_alloc);
+            if (line == NULL)
+                errx(1, "fdrdline: malloc");
         }
         else if (line_alloc < line_len + i + 1) {
             line = realloc(line, line_len + i + 1);
@@ -289,7 +293,47 @@ char *expand_path(const char *path)
 char *mk_str(char *str)
 {
     char *buf = malloc(strlen(str) + 1);
+    if (buf == NULL)
+        errx(1, "mk_str: malloc");
+
     memmove(buf, str, strlen(str) + 1);
     
     return buf;
 }
+
+
+
+char *str_replace(const char *str, const char *old, const char *new)
+{
+    size_t new_size = 0, i = 0;
+    while (i < strlen(str)) {
+        if (i < strlen(str) - strlen(old)
+          && memcmp(str + i, old, strlen(old)) == 0) {
+            i += strlen(old);
+            new_size += strlen(new);
+        }
+        else {
+            new_size += 1;
+            i += 1;
+        }
+    }
+    
+    char *new_str = malloc(new_size + 1);
+    if (new_str == NULL)
+        errx(1, "str_replace: malloc");
+    i = 0;
+    size_t j = 0;
+    while (i < strlen(str)) {
+        if (i < strlen(str) - strlen(old)
+          && memcmp(str + i, old, strlen(old)) == 0) {
+            memmove(new_str + j, new, strlen(new));
+            i += strlen(old);
+            j += strlen(new);
+        }
+        else
+            new_str[j++] = str[i++];
+    }
+    new_str[new_size] = 0;
+    
+    return new_str;
+}
